pub enum AuditExplanationLevel {
Disabled,
Summary,
DependencyPaths,
}Expand description
Amount of latest audit explanation state retained on the graph.
Variants
Disabled
Clear graph-retained explanations and skip explanation indexing.
Summary
Retain bounded latest node/resource/output summaries without dependency paths.
DependencyPaths
Retain summaries plus shortest dependency paths from changed inputs.