OutputFrameKind

Enum OutputFrameKind 

pub enum OutputFrameKind {
    Baseline(OutputPayload),
    Delta(OutputPayload),
    Clear(ClearReason),
    Rebaseline(OutputPayload, RebaselineReason),
}
Data-only output frame kind.

Variants



Baseline(OutputPayload)

Complete current state for a newly attached output.



Delta(OutputPayload)

State-replacement delta for an existing output.



Clear(ClearReason)

Clear the consumer state for this output.



Rebaseline(OutputPayload, RebaselineReason)

Complete current state after an explicit discontinuity.

Implementations

Source

impl OutputFrameKind

pub fn baseline<T>(value: T) -> Self
where T: Clone + PartialEq + Send + Sync + 'static,

Builds a baseline frame kind with a typed payload.

pub fn delta<T>(value: T) -> Self
where T: Clone + PartialEq + Send + Sync + 'static,

Builds a delta frame kind with a typed payload.

pub fn rebaseline<T>(value: T, reason: RebaselineReason) -> Self
where T: Clone + PartialEq + Send + Sync + 'static,

Builds a rebaseline frame kind with a typed payload.

pub fn payload<T>(&self) -> Option<&T>
where T: Clone + PartialEq + Send + Sync + 'static,

Returns this frame payload as the requested type, if this is a payload frame.

pub fn clear_reason(&self) -> Option<ClearReason>

Returns the clear reason, if this is a clear frame.

pub fn rebaseline_reason(&self) -> Option<RebaselineReason>

Returns the rebaseline reason, if this is a rebaseline frame.