pub fn classify_host_resource_status(
status: &HostResourceStatus,
state: Option<HostResourceCommandState>,
duplicate: bool,
) -> HostStatusClassExpand description
Classifies a host resource status against graph command state.
pub fn classify_host_resource_status(
status: &HostResourceStatus,
state: Option<HostResourceCommandState>,
duplicate: bool,
) -> HostStatusClassClassifies a host resource status against graph command state.