pub struct HostResourceCommandState {
pub scope: ScopeId,
pub command_revision: Revision,
pub resource_is_live: bool,
pub scope_owns_resource: bool,
}Expand description
Graph command state needed to classify a host resource status.
Fields
scope: ScopeIdScope associated with the latest command for this resource.
command_revision: RevisionLatest command revision known for this resource.
resource_is_live: boolWhether the resource is still live in graph state.
scope_owns_resource: boolWhether the status scope currently owns the live resource.