NodeMeta

Struct NodeMeta 

pub struct NodeMeta { /* private fields */ }
Inspectable metadata for a graph node.

Implementations

Source

impl NodeMeta

pub fn id(&self) -> NodeId

Returns this node’s id.

pub fn kind(&self) -> NodeKind

Returns this node’s kind.

pub fn debug_name(&self) -> &str

Returns this node’s debug name.

pub fn dependencies(&self) -> &DependencyList

Returns this node’s declared dependencies.

pub fn owning_scope(&self) -> Option<ScopeId>

Returns this node’s owning scope, if one has been attached.

pub fn created_revision(&self) -> Revision

Returns the graph revision at which this node was created.

pub fn last_changed_revision(&self) -> Revision

Returns the graph revision at which this node last changed.