Transaction

Struct Transaction 

pub struct Transaction<'graph, C = (), O = ()> { /* private fields */ }
Staged canonical input transaction.

Implementations

Source

impl<C: 'static, O> Transaction<'_, C, O>
where O: Clone + PartialEq + 'static,

pub fn materialized_output( &mut self, debug_name: impl Into<String>, scope: ScopeId, dependencies: DependencyList, materialize: impl for<'ctx> Fn(&OutputContext<'ctx, C, O>) -> Result<O, OutputError> + Send + Sync + 'static, ) -> GraphResult<MaterializedOutput<O>>

Stages creation of a materialized output with default options.

pub fn materialized_output_with_options( &mut self, debug_name: impl Into<String>, scope: ScopeId, dependencies: DependencyList, options: OutputOptions, materialize: impl for<'ctx> Fn(&OutputContext<'ctx, C, O>) -> Result<O, OutputError> + Send + Sync + 'static, ) -> GraphResult<MaterializedOutput<O>>

Stages creation of a materialized output with explicit options.

pub fn rebaseline_output( &mut self, output: MaterializedOutput<O>, ) -> GraphResult<()>

Stages an explicit output rebaseline.

Source

impl<C: 'static, O> Transaction<'_, C, O>
where O: Clone + PartialEq + 'static,

pub fn map_resource_planner<K, V>( &mut self, collection: CollectionNode<K, V>, scope: ScopeId, planner: impl for<'ctx> Fn(&PlanContext<'ctx, MapDiff<K, V>>) -> Result<ResourcePlan<C>, PlanError> + Send + Sync + 'static, ) -> GraphResult<()>
where K: Clone + Ord + Send + Sync + 'static, V: Clone + PartialEq + Send + Sync + 'static,

Stages a map-diff resource planner.

pub fn set_resource_planner<K>( &mut self, collection: CollectionNode<K, ()>, scope: ScopeId, planner: impl for<'ctx> Fn(&PlanContext<'ctx, SetDiff<K>>) -> Result<ResourcePlan<C>, PlanError> + Send + Sync + 'static, ) -> GraphResult<()>
where K: Clone + Ord + Send + Sync + 'static,

Stages a set-diff resource planner.

Source

impl<'graph, C, O> Transaction<'graph, C, O>
where O: Clone + PartialEq,

pub fn id(&self) -> TransactionId

Returns this transaction’s id.

pub fn set_input<T>(&mut self, input: InputNode<T>, value: T) -> GraphResult<()>
where T: Clone + PartialEq + Send + Sync + 'static,

Stages a typed canonical input change.

pub fn set_input_by_id<T>(&mut self, node: NodeId, value: T) -> GraphResult<()>
where T: Clone + PartialEq + Send + Sync + 'static,

Stages a canonical input change by node id.

pub fn commit(&mut self) -> GraphResult<TransactionResult<C, O>>

Commits staged input changes atomically.

Source

impl<C: 'static, O> Transaction<'_, C, O>
where O: Clone + PartialEq + 'static,

pub fn create_scope( &mut self, debug_name: impl Into<String>, ) -> GraphResult<ScopeId>

Stages creation of a root scope with no parent.

pub fn create_scope_with_parent( &mut self, debug_name: impl Into<String>, parent: Option<ScopeId>, ) -> GraphResult<ScopeId>

Stages creation of a scope with an optional parent.

pub fn close_scope(&mut self, scope: ScopeId) -> GraphResult<()>

Stages closing a scope for resource ownership teardown.

pub fn input<T>( &mut self, debug_name: impl Into<String>, ) -> GraphResult<InputNode<T>>
where T: Clone + PartialEq + Send + Sync + 'static,

Stages creation of an input node.

pub fn derived<T>( &mut self, debug_name: impl Into<String>, dependencies: DependencyList, derive: impl for<'ctx> Fn(&DeriveContext<'ctx, C, O>) -> Result<T, DeriveError> + Send + Sync + 'static, ) -> GraphResult<DerivedNode<T>>
where T: Clone + PartialEq + Send + Sync + 'static,

Stages creation of a derived node with explicit dependencies.

pub fn collection<K, V>( &mut self, debug_name: impl Into<String>, dependencies: DependencyList, derive: impl for<'ctx> Fn(&CollectionContext<'ctx, C, O>) -> Result<BTreeMap<K, V>, DeriveError> + Send + Sync + 'static, ) -> GraphResult<CollectionNode<K, V>>
where K: Clone + Ord + Send + Sync + 'static, V: Clone + PartialEq + Send + Sync + 'static,

Stages creation of a map collection node with explicit dependencies.

pub fn map_collection<K, V>( &mut self, debug_name: impl Into<String>, dependencies: DependencyList, derive: impl for<'ctx> Fn(&CollectionContext<'ctx, C, O>) -> Result<BTreeMap<K, V>, DeriveError> + Send + Sync + 'static, ) -> GraphResult<CollectionNode<K, V>>
where K: Clone + Ord + Send + Sync + 'static, V: Clone + PartialEq + Send + Sync + 'static,

Stages creation of a map collection node with explicit dependencies.

pub fn set_collection<K>( &mut self, debug_name: impl Into<String>, dependencies: DependencyList, derive: impl for<'ctx> Fn(&CollectionContext<'ctx, C, O>) -> Result<BTreeSet<K>, DeriveError> + Send + Sync + 'static, ) -> GraphResult<CollectionNode<K, ()>>
where K: Clone + Ord + Send + Sync + 'static,

Stages creation of a set collection node with explicit dependencies.

pub fn attach_node_to_scope( &mut self, node: impl NodeHandle, scope: ScopeId, ) -> GraphResult<()>

Stages attaching a node to an owning scope.