pub enum AuditEvent {
InputChanged(NodeId),
InputUnchanged(NodeId),
DerivedChanged(NodeId),
CollectionChanged(NodeId),
ScopeCreated(ScopeId),
ScopeClosed(ScopeId),
NodeCreated(NodeId),
NodeAttached {
node: NodeId,
scope: ScopeId,
},
}Expand description
Deterministic transaction event emitted in the audit log.
Variants
InputChanged(NodeId)
An input value changed or was configured to count as changed.
InputUnchanged(NodeId)
An equal input write was skipped by transaction options.
DerivedChanged(NodeId)
A derived value changed.
CollectionChanged(NodeId)
A collection value changed and produced a structural diff.
ScopeCreated(ScopeId)
A scope was created.
ScopeClosed(ScopeId)
A scope was closed.
NodeCreated(NodeId)
A node was created.
NodeAttached
A node was attached to a scope.