pub enum OutputFrameKind {
Baseline(OutputPayload),
Delta(OutputPayload),
Clear(ClearReason),
Rebaseline(OutputPayload, RebaselineReason),
}Expand description
Data-only output frame kind.
Variants
Baseline(OutputPayload)
Complete current state for a newly attached output.
Delta(OutputPayload)
State-replacement delta for an existing output.
Clear(ClearReason)
Clear the consumer state for this output.
Rebaseline(OutputPayload, RebaselineReason)
Complete current state after an explicit discontinuity.
Implementations
Sourceimpl OutputFrameKind
impl OutputFrameKind
Sourcepub fn rebaseline<T>(value: T, reason: RebaselineReason) -> Self
pub fn rebaseline<T>(value: T, reason: RebaselineReason) -> Self
Builds a rebaseline frame kind with a typed payload.
Sourcepub fn payload<T>(&self) -> Option<&T>
pub fn payload<T>(&self) -> Option<&T>
Returns this frame payload as the requested type, if this is a payload frame.
Sourcepub fn clear_reason(&self) -> Option<ClearReason>
pub fn clear_reason(&self) -> Option<ClearReason>
Returns the clear reason, if this is a clear frame.
Sourcepub fn rebaseline_reason(&self) -> Option<RebaselineReason>
pub fn rebaseline_reason(&self) -> Option<RebaselineReason>
Returns the rebaseline reason, if this is a rebaseline frame.