pub struct NodeMeta { /* private fields */ }Expand description
Inspectable metadata for a graph node.
Implementations
Sourceimpl NodeMeta
impl NodeMeta
Sourcepub fn debug_name(&self) -> &str
pub fn debug_name(&self) -> &str
Returns this node’s debug name.
Sourcepub fn dependencies(&self) -> &DependencyList
pub fn dependencies(&self) -> &DependencyList
Returns this node’s declared dependencies.
Sourcepub fn owning_scope(&self) -> Option<ScopeId>
pub fn owning_scope(&self) -> Option<ScopeId>
Returns this node’s owning scope, if one has been attached.
Sourcepub fn created_revision(&self) -> Revision
pub fn created_revision(&self) -> Revision
Returns the graph revision at which this node was created.
Sourcepub fn last_changed_revision(&self) -> Revision
pub fn last_changed_revision(&self) -> Revision
Returns the graph revision at which this node last changed.