pub struct OutputFrameExplanation {
pub output_key: OutputKey,
pub scope: ScopeId,
pub transaction_id: TransactionId,
pub revision: Revision,
pub kind: OutputFrameKindTrace,
pub dependencies: Vec<NodeId>,
pub changed_dependencies: Vec<NodeId>,
pub input_causes: Vec<NodeId>,
pub dependency_paths: Vec<Vec<NodeId>>,
}Expand description
Explanation for the latest frame emitted for an output key.
Fields
output_key: OutputKeyOutput key.
scope: ScopeIdScope that owned the output frame.
transaction_id: TransactionIdTransaction that emitted the frame.
revision: RevisionRevision carried by the frame.
kind: OutputFrameKindTraceFrame kind without materialized payload.
dependencies: Vec<NodeId>Declared dependencies for the output, when still live.
changed_dependencies: Vec<NodeId>Output dependencies that changed in the transaction.
input_causes: Vec<NodeId>Canonical input causes for the frame.
dependency_paths: Vec<Vec<NodeId>>Dependency paths from input causes to changed output dependencies.